from typing import List, Dict
from tqdm import tqdm
import numpy as np
from blueness import module
from abcli import string
from abcli import file
from abcli.plugins.graphics.signature import add_signature
from abcli.plugins.graphics.gif import generate_animated_gif
from abcli.modules.host import signature as host_signature
from abcli.modules.objects import signature as header
from abcli.plugins.metadata import post_to_object
from abcli.modules import objects
from blue_geo import NAME, VERSION
from blue_geo import NAME as BLUE_GEO_NAME
from notebooks_and_scripts import NAME as NBS_NAME, VERSION as NBS_VERSION
from blue_geo.watch.workflow.common import load_watch
from blue_geo.logger import logger


NAME = module.name(__file__, NAME)


def reduce_function(
    query_object_name: str,
    suffix: str,
    object_name: str,
    image_std_threshold: float = 0.02,
    image_content_threshold: float = 0.5,
) -> bool:
    success, target, list_of_files = load_watch(object_name)
    if not success:
        return success

    logger.info(
        "{}.reduce {}/{} @ {} -{} file(s)-> {}".format(
            NAME,
            query_object_name,
            suffix,
            target,
            len(list_of_files),
            object_name,
        )
    )

    bad_images: List[str] = []
    invalid_images: List[str] = []
    list_of_frames: List[str] = []
    frame_metadata: Dict[str:Dict] = {}
    for filename in tqdm(list_of_files):
        success, image = file.load_image(filename)
        if not success:
            bad_images.append(filename)
            continue

        image_fp32 = image.astype(np.float32).flatten() / 255.0
        image_fp32 = image_fp32[image_fp32 > 0.0]
        image_fp32 = image_fp32[image_fp32 < 1.0]
        image_std = np.std(image_fp32) if image_fp32.size else 0.0
        image_content_ratio = len(image_fp32) / image.size

        image_is_valid = bool(
            image_std > image_std_threshold
            and image_content_ratio > image_content_threshold
        )
        logger.info(
            "{} image[{}]: std={:.03f} <?> {:.03f}, content={:.03f} <?> {:.03f}".format(
                "✅" if image_is_valid else "🛑",
                string.pretty_shape_of_matrix(image),
                image_std,
                image_std_threshold,
                image_content_ratio,
                image_content_threshold,
            )
        )
        frame_metadata[file.name_and_extension(filename)] = {
            "content": float(image_content_ratio),
            "shape": list(image.shape),
            "std": float(image_std),
            "valid": image_is_valid,
        }
        if not image_is_valid:
            invalid_images.append(filename)
            continue

        image = add_signature(
            image,
            header=[
                " | ".join(
                    header(file.name(filename), object_name)
                    + [
                        "std: {:.03f}".format(image_std),
                        "{:0.2f}%".format(image_content_ratio * 100.0),
                    ]
                ),
            ],
            footer=[
                str(target),
                " | ".join(
                    [f"{BLUE_GEO_NAME}.{VERSION}"]
                    + [f"{NBS_NAME}.{NBS_VERSION}"]
                    + host_signature()
                ),
            ],
            word_wrap=False,
        )

        frame_filename = file.set_extension(filename, "png")
        if not file.save_image(frame_filename, image):
            bad_images.append(frame_filename)
        else:
            list_of_frames.append(frame_filename)

    if not post_to_object(
        object_name,
        "reduce",
        {
            "bad_images": bad_images,
            "frames": frame_metadata,
            "invalid_images": invalid_images,
            "list_of_files": [
                file.name_and_extension(filename) for filename in list_of_files
            ],
            "target": target.__dict__,
        },
    ):
        return False

    return generate_animated_gif(
        list_of_frames,
        objects.path_of(
            f"{object_name}.gif",
            object_name,
        ),
        frame_duration=1000,
    )



from typing import List
from pystac_client import Client  # https://pystac-client.readthedocs.io/en/stable/
from blue_geo.catalog.generic import GenericCatalog


class CopernicusCatalog(GenericCatalog):
    name = "copernicus"

    url = {
        "": "https://dataspace.copernicus.eu/",
        # https://documentation.dataspace.copernicus.eu/APIs/STAC.html
        "api": "https://catalogue.dataspace.copernicus.eu/stac",
        "aws_access": "https://documentation.dataspace.copernicus.eu/APIs/S3.html",
        "doc": "https://documentation.dataspace.copernicus.eu/APIs/STAC.html",
        "docs": "https://documentation.dataspace.copernicus.eu/APIs/STAC.html",
    }

    def get_list_of_collections(self) -> List[str]:
        client = Client.open(self.url["api"])
        return sorted([collection.id for collection in client.get_collections()])



import os
from abcli.env import load_env, load_config

load_env(__name__)
load_config(__name__)

# secrets
FIRMS_MAP_KEY = os.getenv(
    "FIRMS_MAP_KEY",
    "",
)

COPERNICUS_AWS_ACCESS_KEY_ID = os.getenv(
    "COPERNICUS_AWS_ACCESS_KEY_ID",
    "",
)

COPERNICUS_AWS_SECRET_ACCESS_KEY = os.getenv(
    "COPERNICUS_AWS_SECRET_ACCESS_KEY",
    "",
)

# QGIS templates
BLUE_GEO_QGIS_TEMPLATE_FIRMS_AREA = os.getenv(
    "BLUE_GEO_QGIS_TEMPLATE_FIRMS_AREA",
    "",
)

BLUE_GEO_QGIS_TEMPLATE_UKRAINE_TIMEMAP = os.getenv(
    "BLUE_GEO_QGIS_TEMPLATE_UKRAINE_TIMEMAP",
    "",
)

BLUE_GEO_QGIS_TEMPLATE_WATCH = os.getenv(
    "BLUE_GEO_QGIS_TEMPLATE_WATCH",
    "",
)


# test datacube-ids
BLUE_GEO_TEST_DATACUBE_COPERNICUS_SENTINEL_2 = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_COPERNICUS_SENTINEL_2",
    "",
)
BLUE_GEO_TEST_DATACUBE_COPERNICUS_SENTINEL_2_CHILCOTIN = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_COPERNICUS_SENTINEL_2_CHILCOTIN",
    "",
)

BLUE_GEO_TEST_DATACUBE_CROP_CTULINE = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_CROP_CTULINE",
    "",
)

BLUE_GEO_TEST_DATACUBE_FIRMS_AREA = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_FIRMS_AREA",
    "",
)

BLUE_GEO_TEST_DATACUBE_GENERIC_GENERIC = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_GENERIC_GENERIC",
    "",
)

BLUE_GEO_TEST_DATACUBE_UKRAINE_TIMEMAP = os.getenv(
    "BLUE_GEO_TEST_DATACUBE_UKRAINE_TIMEMAP",
    "",
)



import os
from typing import Any, Tuple, Dict, List, Union
import boto3
from datetime import datetime, timedelta
from pystac_client import Client
from tqdm import tqdm
from blueness import module
from abcli import file, path, string
from abcli.modules import objects
from blue_geo import NAME
from blue_geo import env
from abcli.plugins.metadata import post_to_object
from blue_geo.catalog.copernicus.classes import CopernicusCatalog
from blue_geo.catalog.generic.generic.classes import GenericDatacube
from blue_geo.logger import logger

NAME = module.name(__file__, NAME)


class CopernicusSentinel2Datacube(GenericDatacube):
    name = "sentinel_2"

    catalog = CopernicusCatalog()

    metadata: Any = {}

    query_args = {
        "bbox": {
            "type": str,
            "default": "",
            "help": "<-122.88,51.73,-122.68,51.93>",
        },
        "datetime": {
            "default": "{}/{}".format(
                (datetime.now() - timedelta(days=30)).strftime("%Y-%m-%d"),
                datetime.now().strftime("%Y-%m-%d"),
            ),
            "help": "<2024-07-30/2024-08-09>",
        },
        "lat": {
            "type": float,
            "default": 51.83,
            "help": "<51.83>",
        },
        "lon": {
            "type": float,
            "default": -122.78,
            "help": "<-122.78>",
        },
        "count": {
            "type": int,
            "default": -1,
            "help": "<10>, -1: all",
        },
        "radius": {
            "type": float,
            "default": 0.1,
            "help": "<0.1>",
        },
    }

    QGIS_template = "unknown-template"

    def get_bucket(self, verbose: bool = False) -> Tuple[bool, Any, str]:
        try:
            href = (
                self.metadata["Item"]
                .assets["PRODUCT"]
                .extra_fields.get("alternate")["s3"]["href"]
            )
        except:
            return False, None, ""

        bucket_name, s3_prefix = href.split("/", 2)[1:3]

        if verbose:
            logger.info(f"href: {href}")
            logger.info(f"bucket_name: {bucket_name}")
            logger.info(f"s3_prefix: {s3_prefix}")

        s3 = boto3.resource(
            "s3",
            endpoint_url="https://eodata.dataspace.copernicus.eu",
            aws_access_key_id=env.COPERNICUS_AWS_ACCESS_KEY_ID,
            aws_secret_access_key=env.COPERNICUS_AWS_SECRET_ACCESS_KEY,
            region_name="default",
        )

        bucket = s3.Bucket(bucket_name)

        return True, bucket, s3_prefix

    @classmethod
    def get_client(cls) -> Tuple[bool, Union[Client, None]]:
        try:
            client = Client.open(cls.catalog.url["api"])
        except Exception as e:
            logger.error(e)
            return False, None

        return True, client

    def ingest(
        self,
        dryrun: bool = False,
        overwrite: bool = False,
        what: str = "metadata",
        verbose: bool = False,
    ) -> Tuple[bool, Any]:
        success, output = super().ingest(dryrun, overwrite, what)
        if not success:
            return success, output

        download_all = what == "all"
        download_quick = what == "quick"
        suffix = "" if download_all or download_quick or what == "metadata" else what

        success, bucket, s3_prefix = self.get_bucket(verbose=True)
        if not success:
            return success, output

        datacube_path = objects.object_path(self.datacube_id)
        if not path.create(datacube_path):
            return False, output

        list_of_items = bucket.objects.filter(Prefix=s3_prefix)

        error_count = 0
        TCI_downloaded = False
        for item in tqdm(list_of_items):
            item_suffix = item.key.split(f"{s3_prefix}/", 1)[1]
            if not item_suffix:
                continue

            item_filename = os.path.join(datacube_path, item_suffix)
            if not path.create(file.path(item_filename)):
                error_count += 1
                continue
            if item_filename.endswith(os.sep):
                continue

            skip = True
            if download_all:
                skip = False
            elif item.size <= 10**6 and not any(
                item_filename.endswith(suffix)
                for suffix in [
                    ".jp2",
                    ".tif",
                    ".tiff",
                ]
            ):
                skip = False
            elif (
                download_quick
                and not TCI_downloaded
                and item_filename.endswith(".jp2")
                and "TCI" in item_filename
            ):
                TCI_downloaded = True
                skip = False
            elif suffix and item_filename.endswith(suffix):
                skip = False

            if skip:
                if verbose:
                    logger.info(
                        "skipped {}: {}".format(
                            string.pretty_bytes(item.size),
                            item_suffix,
                        )
                    )
                continue

            if not overwrite and file.exist(item_filename):
                logger.info(f"✅ {item_filename}")
                continue

            logger.info(
                "downloading {}: {} -> {}".format(
                    string.pretty_bytes(item.size),
                    item_suffix,
                    item_filename,
                )
            )
            if dryrun:
                continue

            try:
                bucket.download_file(item.key, item_filename)
            except Exception as e:
                logger.error(e)
                error_count += 1
                continue

        if error_count:
            logger.error(f"{error_count} error(s).")

        return error_count == 0, output

    def list_of_files(self) -> List[str]:
        success, bucket, s3_prefix = self.get_bucket()
        if not success:
            return []

        list_of_items = bucket.objects.filter(Prefix=s3_prefix)

        return [item.key.split(f"{s3_prefix}/", 1)[1] for item in list_of_items]

    @classmethod
    def parse_datacube_id(cls, datacube_id: str) -> Tuple[
        bool,
        Dict[str, Any],
    ]:
        success, _ = super().parse_datacube_id(datacube_id)
        if not success:
            return False, {}

        # datacube-copernicus-sentinel_1-<item_id>
        segments = datacube_id.split("-")
        if len(segments) < 4:
            return False, {}

        if segments[2] != cls.name:
            return False, {}

        return True, {
            "item_id": datacube_id.split("-", 4)[3],
        }

    @classmethod
    def query(
        cls,
        object_name: str,
        datetime: str,
        bbox: List[float],
        count: int,
        verbose: bool = False,
    ) -> bool:
        logger.info(f"🔎 {cls.__name__}.query -> {object_name}")

        success, client = cls.get_client()
        if not success:
            return success

        search_parameters = {
            "collections": ["SENTINEL-2"],
            "bbox": bbox,
            "datetime": datetime,
        }
        for param, value in search_parameters.items():
            logger.info(f"🔎 {param}: {value}")

        try:
            search = client.search(**search_parameters)
        except Exception as e:
            logger.error(e)
            return False

        items = list(search.item_collection())
        if verbose:
            for item in items:
                logger.info(
                    "🧊 {}: {} @ {}".format(
                        item.id, item.datetime, ", ".join(list(item.assets.keys()))
                    )
                )

        list_of_datacube_ids: List[str] = sorted(
            [
                "datacube-{}-{}-{}".format(
                    cls.catalog.name,
                    cls.name,
                    item.id.replace(".SAFE", "-SAFE"),
                )
                for item in items
            ]
        )
        if count != -1:
            list_of_datacube_ids = list_of_datacube_ids[:count]
        logger.info(f"{len(list_of_datacube_ids)} datacubes(s) found.")
        for index, datacube_id in enumerate(list_of_datacube_ids):
            logger.info(f"🧊 {index+1:02}: {datacube_id}")

        return post_to_object(
            object_name,
            "datacube_id",
            list_of_datacube_ids,
        )

    def update_metadata(self, verbose: bool = False) -> bool:
        if not super().update_metadata(verbose):
            return False

        success, client = self.get_client()
        if not success:
            return success

        segments = self.datacube_id.replace("-SAFE", ".SAFE").split("-", 3)
        assert len(segments) == 4, self.datacube_id
        search_parameters = {"ids": [segments[3]]}

        if verbose:
            for param, value in search_parameters.items():
                logger.info(f"{param}: {value}")

        search = client.search(**search_parameters)

        items = list(search.item_collection())
        if not items:
            return False
        if len(items) != 1 and verbose:
            logger.waring(
                "{}.update_metadata({}): {} instance(s) found.".format(
                    NAME,
                    self.datacube_id,
                    len(items),
                )
            )
        item = items[0]
        if verbose:
            logger.info(
                "🧊 {}: {} @ {}".format(
                    item.id, item.datetime, ", ".join(list(item.assets.keys()))
                )
            )
        self.metadata["Item"] = item

        success, bucket, s3_prefix = self.get_bucket(verbose)

        list_of_files = [
            item.key.split(f"{s3_prefix}/", 1)[1]
            for item in bucket.objects.filter(Prefix=s3_prefix)
        ]
        self.metadata["files"] = list_of_files

        if verbose:
            logger.info(f"{len(list_of_files)} file(s).")
            for index, filename in enumerate(list_of_files):
                logger.info(f"#{index+1}: {filename}")

        return True



import argparse
from blueness import module
from abcli import file
from blue_geo import NAME, VERSION
from blue_geo.catalog import get_datacube
from blue_geo.logger import logger
from blueness.argparse.generic import sys_exit

NAME = module.name(__file__, NAME)


parser = argparse.ArgumentParser(NAME, description=f"{NAME}-{VERSION}")
parser.add_argument(
    "task",
    type=str,
    help="get|ingest",
)
parser.add_argument(
    "--what",
    default="",
    type=str,
    help="get:catalog|list_of_files|template, ingest: all|metadata|quick|<suffix>",
)
parser.add_argument(
    "--datacube_id",
    type=str,
    default="",
)
parser.add_argument(
    "--catalog",
    type=str,
    default="",
)
parser.add_argument(
    "--dryrun",
    default=0,
    type=int,
    help="0|1",
)
parser.add_argument(
    "--overwrite",
    default=0,
    type=int,
    help="0|1",
)
parser.add_argument(
    "--suffix",
    default="",
    type=str,
    help="<.jp2+.tif+.tiff>",
)
parser.add_argument(
    "--delim",
    type=str,
    default="+",
)
parser.add_argument(
    "--count",
    type=int,
    default=-1,
    help="-1: all",
)
parser.add_argument(
    "--exists",
    type=int,
    default=0,
    help="0|1",
)
args = parser.parse_args()

delim = " " if args.delim == "space" else args.delim

success = False
if args.task == "get":
    success = True
    datacube = get_datacube(datacube_id=args.datacube_id)

    output = f"unknown-{args.what}"
    if args.what == "catalog":
        output = datacube.catalog.name
    elif args.what == "list_of_files":
        list_of_files = [
            filename
            for filename in datacube.list_of_files()
            if any(filename.endswith(suffix) for suffix in args.suffix.split("+"))
        ]

        if args.exists == 1:
            list_of_files = [
                filename
                for filename in list_of_files
                if file.exist(datacube.full_filename(filename))
            ]

        if args.count != -1:
            list_of_files = list_of_files[: args.count]

        output = delim.join(list_of_files)
    elif args.what == "template":
        output = datacube.QGIS_template

    print(output)
elif args.task == "ingest":
    datacube = get_datacube(datacube_id=args.datacube_id)
    success, _ = datacube.ingest(
        dryrun=args.dryrun == 1,
        overwrite=args.overwrite == 1,
        what=args.what if args.what else "metadata",
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from blueness import module
from abcli import file
from abcli.plugins.metadata import post_to_object
from blue_geo import NAME
from blue_geo.watch.workflow.common import load_watch
from blue_geo.logger import logger


NAME = module.name(__file__, NAME)


def map_function(
    datacube_id: str,
    object_name: str,
) -> bool:
    success, target, list_of_files = load_watch(object_name)
    if not success or not list_of_files:
        return success
    filename = list_of_files[0]

    logger.info(
        "{}.map: {} @ {} -> {}".format(
            NAME,
            target,
            datacube_id,
            object_name,
        )
    )

    return post_to_object(
        object_name,
        "map",
        {
            "datacube_id": datacube_id,
            "filename": file.name_and_extension(filename),
            "target": target.__dict__,
        },
    )



import os
import argparse
from blueness import module
from abcli import file
from blue_geo import NAME, VERSION
from blue_geo.watch.targets.classes import TargetList
from blue_geo.watch.workflow.generation import generate_workflow
from blue_geo.watch.workflow.map import map_function
from blue_geo.watch.workflow.reduce import reduce_function
from blue_geo.logger import logger
from blueness.argparse.generic import sys_exit

NAME = module.name(__file__, NAME)

list_of_tasks = "generate|map|reduce"


parser = argparse.ArgumentParser(NAME, description=f"{NAME}-{VERSION}")
parser.add_argument(
    "task",
    type=str,
    help=list_of_tasks,
)
parser.add_argument(
    "--job_name",
    type=str,
)
parser.add_argument(
    "--map_options",
    type=str,
)
parser.add_argument(
    "--reduce_options",
    type=str,
)
parser.add_argument(
    "--datacube_id",
    type=str,
)
parser.add_argument(
    "--object_name",
    type=str,
)
parser.add_argument(
    "--query_object_name",
    type=str,
)
parser.add_argument(
    "--suffix",
    type=str,
)
args = parser.parse_args()

success = args.task in list_of_tasks
target_list = TargetList(os.path.join(file.path(__file__), "targets.yaml"))
if args.task == "generate":
    success = generate_workflow(
        query_object_name=args.query_object_name,
        job_name=args.job_name,
        object_name=args.object_name,
        map_options=args.map_options,
        reduce_options=args.reduce_options,
    )
elif args.task == "map":
    success = map_function(
        args.datacube_id,
        args.object_name,
    )
elif args.task == "reduce":
    success = reduce_function(
        query_object_name=args.query_object_name,
        suffix=args.suffix,
        object_name=args.object_name,
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



import copy
from typing import Dict, Tuple
from abcli import file
from abcli.modules import objects
from abcli.file.load import load_yaml
import geopandas as gpd
from shapely.geometry import Polygon
from blue_geo.logger import logger


class Target:
    def __init__(
        self,
        name: str = "",
        catalog: str = "",
        collection: str = "",
        params: Dict[str, str] = {},
        query_args: Dict[str, str] = {},
    ) -> None:
        self.name: str = name

        self.catalog = catalog
        self.collection = collection

        self.params = copy.deepcopy(params)
        self.query_args = copy.deepcopy(query_args)

    def __repr__(self) -> str:
        return "{}: {} | {}/{} | {}".format(
            self.__class__.__name__,
            self.name,
            self.catalog,
            self.collection,
            self.query_args_as_str(" | "),
        )

    @classmethod
    def from_dict(
        cls,
        name: str,
        data: Dict,
    ) -> "Target":
        return cls(
            name=name,
            catalog=data.get("catalog", ""),
            collection=data.get("collection", ""),
            params=copy.deepcopy(data.get("params", {})),
            query_args=copy.deepcopy(data.get("query_args", {})),
        )

    @classmethod
    def load(cls, object_name: str) -> Tuple[bool, "Target"]:
        success, metadata = file.load_yaml(
            objects.path_of(
                "target/metadata.yaml",
                object_name,
            )
        )

        return success, Target.from_dict(
            metadata.get("name", ""),
            metadata,
        )

    def query_args_as_str(self, delim: str = " ") -> str:
        return delim.join(
            [f"--{argument} {value}" for argument, value in self.query_args.items()]
        )

    def save(self, object_name: str) -> bool:
        if not file.save_yaml(
            objects.path_of(
                "target/metadata.yaml",
                object_name,
                create=True,
            ),
            self.__dict__,
        ):
            return False

        lat = self.query_args.get("lat", 0)
        lon = self.query_args.get("lon", 0)
        width = self.params.get("width", 0.1)
        height = self.params.get("height", 0.1)

        half_width = width / 2
        half_height = height / 2

        top_left = (lon - half_width, lat + half_height)
        top_right = (lon + half_width, lat + half_height)
        bottom_right = (lon + half_width, lat - half_height)
        bottom_left = (lon - half_width, lat - half_height)

        polygon = Polygon([top_left, top_right, bottom_right, bottom_left, top_left])

        gdf = gpd.GeoDataFrame(
            {
                "id": ["1"],
                "description": [self.name],
                "geometry": [polygon],
            },
            crs="EPSG:4326",
        )

        return file.save_geojson(
            objects.path_of("target/shape.geojson", object_name),
            gdf,
            log=True,
        )


class TargetList:
    def __init__(self, filename: str = "") -> None:
        self.targets: Dict[str, Target] = {}

        if filename:
            self.load(filename)

    def load(self, filename: str) -> bool:
        self.targets = {}

        success, targets = load_yaml(filename, civilized=True)

        for target_name, target_info in targets.items():
            self.targets[target_name] = Target.from_dict(
                target_name,
                target_info,
            )

        return success



import argparse
from blueness import module
from blue_geo import NAME, VERSION
from blue_geo.QGIS.seed import generate_seed
from blue_geo.logger import logger
from blueness.argparse.generic import sys_exit

NAME = module.name(__file__, NAME)


parser = argparse.ArgumentParser(
    f"python3 -m {NAME}",
    description=f"{NAME}-{VERSION}",
)
parser.add_argument(
    "task",
    type=str,
    help="generate_seed",
)
args = parser.parse_args()

success = False
if args.task == "generate_seed":
    success = True
    print(generate_seed())
else:
    success = None

sys_exit(logger, NAME, args.task, success)



import argparse
from blueness import module
from blue_geo import NAME, VERSION
from blue_geo.catalog.default import add_default_arguments
from blue_geo.catalog.copernicus.sentinel_2.classes import CopernicusSentinel2Datacube
from blue_geo.logger import logger
from blueness.argparse.generic import sys_exit

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME, description=f"{NAME}-{VERSION}")
parser.add_argument(
    "task",
    type=str,
    help="query",
)
add_default_arguments(CopernicusSentinel2Datacube.query_args, parser)
parser.add_argument(
    "--object_name",
    type=str,
    default="",
)
args = parser.parse_args()


success = False
if args.task == "query":
    success = CopernicusSentinel2Datacube.query(
        object_name=args.object_name,
        bbox=(
            [float(item) for item in args.bbox.split(",") if item]
            if args.bbox
            else [
                args.lon - args.radius,
                args.lat - args.radius,
                args.lon + args.radius,
                args.lat + args.radius,
            ]
        ),
        datetime=args.datetime,
        count=args.count,
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)
